==> facebook-core-7.0.1-sources.jar: com/facebook/internal/SmartLoginOption.java <==
/*
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.facebook.internal;

import java.util.EnumSet;

public enum SmartLoginOption {
  None(0),
  Enabled(1),
  RequireConfirm(2);

  public static final EnumSet<SmartLoginOption> ALL = EnumSet.allOf(SmartLoginOption.class);

  public static EnumSet<SmartLoginOption> parseOptions(long bitmask) {
    EnumSet<SmartLoginOption> result = EnumSet.noneOf(SmartLoginOption.class);
    for (SmartLoginOption opt : ALL) {
      if ((bitmask & opt.getValue()) != 0) {
        result.add(opt);
      }
    }
    return result;
  }

  private final long mValue;

  SmartLoginOption(long value) {
    this.mValue = value;
  }

  public long getValue() {
    return mValue;
  }
}

==> facebook-core-8.0.0-sources.jar: com/facebook/internal/SmartLoginOption.java <==
/*
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.facebook.internal;

import com.facebook.internal.qualityvalidation.Excuse;
import com.facebook.internal.qualityvalidation.ExcusesForDesignViolations;
import java.util.EnumSet;

@ExcusesForDesignViolations(@Excuse(type = "MISSING_UNIT_TEST", reason = "Enum"))
public enum SmartLoginOption {
  None(0),
  Enabled(1),
  RequireConfirm(2);

  public static final EnumSet<SmartLoginOption> ALL = EnumSet.allOf(SmartLoginOption.class);

  public static EnumSet<SmartLoginOption> parseOptions(long bitmask) {
    EnumSet<SmartLoginOption> result = EnumSet.noneOf(SmartLoginOption.class);
    for (SmartLoginOption opt : ALL) {
      if ((bitmask & opt.getValue()) != 0) {
        result.add(opt);
      }
    }
    return result;
  }

  private final long mValue;

  SmartLoginOption(long value) {
    this.mValue = value;
  }

  public long getValue() {
    return mValue;
  }
}
